@@ -1,6 +1,6 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab
 /*
-Gwenview - A simple image viewer for KDE
+Gwenview - A simple image viewer for TDE
 Copyright 2000-2004 Aurlien Gteau
  
  This program is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@ class KService;
 namespace Gwenview {
 class LIBGWENVIEW_EXPORT ExternalToolContext : public TQObject {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	ExternalToolContext(TQObject* parent,
 		std::list<KService*> services,
