@@ -1,6 +1,6 @@
 // vi: tabstop=4 shiftwidth=4 noexpandtab
 /*
-Gwenview - A simple image viewer for KDE
+Gwenview - A simple image viewer for TDE
 Copyright 2005 Aurelien Gateau
 
 This program is free software; you can redistribute it and/or
@@ -30,7 +30,7 @@ class FileThumbnailView;
 
 class ThumbnailDetailsDialog : public KDialogBase {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	ThumbnailDetailsDialog(FileThumbnailView* view);
 	~ThumbnailDetailsDialog();
