@@ -1,6 +1,6 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab:
 /*
-Gwenview - A simple image viewer for KDE
+Gwenview - A simple image viewer for TDE
 Copyright 2000-2006 Aurélien Gâteau
 
 This program is free software; you can redistribute it and/or
@@ -22,10 +22,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // KDE
 #include <kdebug.h>
-#include <kfileitem.h>
-#include <kfilemetainfo.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdefileitem.h>
+#include <tdefilemetainfo.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 	
 namespace Gwenview {
 namespace TimeUtils {
@@ -39,13 +39,13 @@ time_t getTime(const KFileItem* item) {
 			return dt.toTime_t();
 		}
 	}
-	return item->time(KIO::UDS_MODIFICATION_TIME);
+	return item->time(TDEIO::UDS_MODIFICATION_TIME);
 }
 
 TQString formatTime(time_t time) {
 	TQDateTime dt;
 	dt.setTime_t(time);
-	return KGlobal::locale()->formatDateTime(dt);
+	return TDEGlobal::locale()->formatDateTime(dt);
 }
 
 
